Rename entire project from `fw' to `fwd'.
[fwd] / fwd.c
diff --git a/fw.c b/fwd.c
similarity index 97%
rename from fw.c
rename to fwd.c
index 4b0a861..d80275b 100644 (file)
--- a/fw.c
+++ b/fwd.c
@@ -7,24 +7,24 @@
 
 /*----- Licensing notice --------------------------------------------------*
  *
* This file is part of the `fw' port forwarder.
  *
* `fw' is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
* `fw' is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
* along with `fw'; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "fw.h"
+#include "fwd.h"
 
 /*----- Global variables --------------------------------------------------*/
 
@@ -74,7 +74,7 @@ void parse(scanner *sc)
     /* --- Handle a forwarding request --- */
 
     if (strcmp(sc->d.buf, "forward") == 0 ||
-       strcmp(sc->d.buf, "fw") == 0 ||
+       strcmp(sc->d.buf, "fwd") == 0 ||
        strcmp(sc->d.buf, "from") == 0) {
       source *s;
       target *t;
@@ -264,7 +264,7 @@ void fw_log(time_t t, const char *fmt, ...)
  *
  * Returns:    ---
  *
* Use:                Increments or decrements the active thing count.  `fw' won't
  *             quit while there are active things.
  */
@@ -7,24 +7,24 @@
 /*----- Licensing notice --------------------------------------------------*
  *
- * This file is part of the `fw' port forwarder.
+ * This file is part of the `fwd' port forwarder.
  *
@@ -7,24 +7,24 @@
  *
- * `fw' is free software; you can redistribute it and/or modify
+ * `fwd' is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -7,24 +7,24 @@
  * (at your option) any later version.
  *
- * `fw' is distributed in the hope that it will be useful,
+ * `fwd' is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -7,24 +7,24 @@
  *
  * You should have received a copy of the GNU General Public License
- * along with `fw'; if not, write to the Free Software Foundation,
+ * along with `fwd'; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -264,7 +264,7 @@ void fw_log(time_t t, const char *fmt, ...)
  * Returns:    ---
  *
- * Use:                Increments or decrements the active thing count.  `fw' won't
+ * Use:                Increments or decrements the active thing count.  `fwd' won't
  *             quit while there are active things.
  */